@@ -76,7 +76,8 @@ class BitmexClient:
                 # print('Current price expired error. Time:', now, ' Server Time:', now.strftime("%m/%d/%Y, %H:%M:%S"), 'Returning last price.', flush=True)
                 print('Current price expired error. Returning last price.', flush=True)
             else:
-                print('API error getting current price', e, flush=True)
+                # print('API error getting current price', e, flush=True)
+                pass
             return self.last_current_price(symbol)
         
     def last_current_price(self, symbol):
