@@ -51,7 +51,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
             pos_size = input(
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
-            symbol_settings[symbol] = {'position_size': pos_size, 'last_order_id': ''}
+            symbol_settings[symbol] = {'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': ''}
         return make_pickle_file(setting_name, token, api_key, api_secret, symbol_settings)
 
 
