@@ -38,6 +38,10 @@ class Lotus:
                 "Invalid API ID or API Secret, please restart and provide the right keys", flush=True)
             sys.exit()
 
+    # helper function
+    def ceil_dt(dt, delta):
+        return dt + (datetime.datetime.min - dt) % delta
+
     def is_new_signal_symbol(self, signal, symbol):
         timestamp = parser.parse(signal[symbol]['timestamp'])
         if self._last_timestamp[symbol] != timestamp:
@@ -93,7 +97,6 @@ class Lotus:
                     self.order.check_open_bot_order(symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
                     time.sleep(3)
             signal = ns[symbol]['signal']
-            print('Signal: {}'.format(signal), flush=True)
             if signal:
                 if self.is_new_signal_symbol(ns, symbol):
                     entry = ns[symbol]['entry']
@@ -171,7 +174,8 @@ class Lotus:
                             self.order.close(symbol)
             else:
                 self.manage_open_stop_orders(symbol)
-                print("This signal in {} is only for paid members.".format(symbol), flush=True)
+                print("This position update in {} is only for premium members. Next update: {}".format(symbol,
+                self.ceil_dt(datetime.datetime.now(), datetime.timedelta(minutes=30))), flush=True)
 
     def run(self):
         # Main loop
@@ -185,6 +189,7 @@ class Lotus:
             else:
                 self.process_signals(signal, start=True)
                 break
+        print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
         while True:
             time.sleep(10)
             self.order.manage_entries(self.symbols)
